function seq = btd_aa2nt(n)
    
  // Amino Acid Sequence to Nucleotide Sequence
  // 
  // Calling Sequence
  //   y = btd_aa2nt ( x )
  // 
  // Parameters
  //   x : String of single-letter codes specifying an amino acid sequence
  //   y : Nucleotide sequence specified by a character string of letter codes.
  // 
  // Description
  // Convert amino acid sequence to nucleotide sequence
  // 
  // Examples
  // y = btd_aa2nt('KAEPLLQ')
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, 2015
  
    ip = mstr2sci(n);
    l = length(n);
    
    for i = 1:l
        if(ip(i)=="M")
            out(i) = "ATG";
        elseif(ip(i)=="W")
            out(i) = "TGG";
        elseif(ip(i)=="K")
            num1= grand(1, "prm", (1:2)')';
            n1 = num1(1:1);
            if(n1 == 1)
                out(i)="AAA";
            elseif(n1 == 2)
                out(i)="AAG";
            end
        elseif(ip(i)=="N")
            num2= grand(1, "prm", (1:2)')';
            n2 = num2(1:1);
            if(n2 == 1)
                out(i)="AAC";
            elseif(n2 == 2)
                out(i)="AAT";
            end
        elseif(ip(i)=="Q")
            num3= grand(1, "prm", (1:2)')';
            n3 = num3(1:1);
            if(n3 == 1)
                out(i)="CAA";
            elseif(n3 == 2)
                out(i)="CAG";
            end
        elseif(ip(i)=="H")
            num4= grand(1, "prm", (1:2)')';
            n4 = num4(1:1);
            if(n4 == 1)
                out(i)="CAC";
            elseif(n4 == 2)
                out(i)="CAT";
            end
        elseif(ip(i)=="E")
            num5= grand(1, "prm", (1:2)')';
            n5 = num5(1:1);
            if(n5 == 1)
                out(i)="GAA";
            elseif(n5 == 2)
                out(i)="GAG";
            end
        elseif(ip(i)=="D")
            num6= grand(1, "prm", (1:2)')';
            n6 = num6(1:1);
            if(n6 == 1)
                out(i)="GAC";
            elseif(n6 == 2)
                out(i)="GAT";
            end
        elseif(ip(i)=="Y")
            num7= grand(1, "prm", (1:2)')';
            n7 = num7(1:1);
            if(n7 == 1)
                out(i)="TAC";
            elseif(n7 == 2)
                out(i)="TAT";
            end
        elseif(ip(i)=="C")
            num8= grand(1, "prm", (1:2)')';
            n8 = num8(1:1);
            if(n8 == 1)
                out(i)="TGC";
            elseif(n8 == 2)
                out(i)="TGT";
            end
        elseif(ip(i)=="F")
            num9= grand(1, "prm", (1:2)')';
            n9 = num9(1:1);
            if(n9 == 1)
                out(i)="TTC";
            elseif(n9 == 2)
                out(i)="TTT";
            end
        elseif(ip(i)=="I")
            num10= grand(1, "prm", (1:3)')';
            n10 = num10(1:1);
            if(num10 == 1)
                out(i)="AAT";
            elseif(n10 == 2)
                out(i)="ATA";
            elseif(n10 == 3)
                out(i)="ATC";
            end
        elseif(ip(i)=="*")
            num11= grand(1, "prm", (1:3)')';
            n11 = num11(1:1);
            if(n11 == 1)
                out(i)="TAA";
            elseif(n11 == 2)
                out(i)="TAG";
            elseif(n11 == 3)
                out(i)="TGA";
            end
        elseif(ip(i)=="T")
            num12= grand(1, "prm", (1:4)')';
            n12 = num12(1:1);
            if(n12 == 1)
                out(i)="ACA";
            elseif(n12 == 2)
                out(i)="ACC";
            elseif(n12 == 3)
                out(i)="ACG";
            elseif(n12 == 4)
                out(i)="ACT";
            end
        elseif(ip(i)=="P")
            num13= grand(1, "prm", (1:4)')';
            n13 = num13(1:1);
            if(n13 == 1)
                out(i)="CCA";
            elseif(n13 == 2)
                out(i)="CCC";
            elseif(n13 == 3)
                out(i)="CCG";
            elseif(n13 == 4)
                out(i)="CCT";
            end
        elseif(ip(i)=="R")
            num14= grand(1, "prm", (1:4)')';
            n14 = num14(1:1);
            if(n14 == 1)
                out(i)="CGA";
            elseif(n14 == 2)
                out(i)="CGC";
            elseif(n14 == 3)
                out(i)="CGG";
            elseif(n14 == 4)
                out(i)="CGT";
            end
        elseif(ip(i)=="A")
            num15= grand(1, "prm", (1:4)')';
            n15 = num15(1:1);
            if(n15 == 1)
                out(i)="GCA";
            elseif(n15 == 2)
                out(i)="GCC";
            elseif(n15 == 3)
                out(i)="GCG";
            elseif(n15 == 4)
                out(i)="GCT";
            end
        elseif(ip(i)=="G")
            num16= grand(1, "prm", (1:4)')';
            n16 = num16(1:1);
            if(n16 == 1)
                out(i)="GGA";
            elseif(n16 == 2)
                out(i)="GGC";
            elseif(n16 == 3)
                out(i)="GGG";
            elseif(n16 == 4)
                out(i)="GGT";
            end
        elseif(ip(i)=="V")
            num17= grand(1, "prm", (1:4)')';
            n17 = num17(1:1);
            if(n17 == 1)
                out(i)="GTA";
            elseif(n17 == 2)
                out(i)="GTC";
            elseif(n17 == 3)
                out(i)="GTG";
            elseif(n17 == 4)
                out(i)="GTT";
            end
        elseif(ip(i)=="S")
            num18= grand(1, "prm", (1:4)')';
            n18 = num18(1:1);
            if(n18 == 1)
                out(i)="TCA";
            elseif(n18 == 2)
                out(i)="TCC";
            elseif(n18 == 3)
                out(i)="TCG";
            elseif(n18 == 4)
                out(i)="TCT";
            end
        elseif(ip(i)=="L")
            num19= grand(1, "prm", (1:6)')';
            n19 = num19(1:1);
            if(n19 == 1)
                out(i)="CTA";
            elseif(n19 == 2)
                out(i)="CTC";
            elseif(n19 == 3)
                out(i)="CTG";
            elseif(n19 == 4)
                out(i)="CTT";
            elseif(n19 == 5)
                out(i)="TTA";
            elseif(n19 == 6)
                out(i)="TTG";
            end
        end
    end
    seq = strcat(out);
endfunction
