function val = btd_at2gcratio (s)
    
  // AT/GC Ratio
  // 
  // Calling Sequence
  //   y = btd_at2gcratio ( x )
  // 
  // Parameters
  //   x : String of single-letter codes specifying a DNA/RNA sequence
  //   y : Ratio of AT/GC
  // 
  // Description
  // To compute the ratio between AT and GC
  // 
  // Examples
  // y = btd_at2gcratio("ACTCTAGCTACT")
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, Priyadharshini K, Aswathi B L, Vidya R V, 2015
    
    l = length(s);
    n = strsubst(s, 'U', 'T');
    seq = mstr2sci(n);
    
    //AT content
    A = grep(seq, 'A');
    Ta = length(A);
    T = grep(seq, 'T');
    Tt = length(T);
    
    ATcontent = Ta + Tt;
    
    //GC content
    G = grep(seq, 'G');
    Tg = length(G);
    C = grep(seq, 'C');
    Tc = length(C);
    
    GCcontent = Tg + Tc;
    
    //AT2GC Ratio
    val = ATcontent/GCcontent;
    
endfunction


