function val = btd_atomiccomp(ip)
    
   // Atomic Composition 
  // 
  // Calling Sequence
  //   y = btd_atomiccomp ( x )
  // 
  // Parameters
  //   x : Amino acid sequence
  //   y : Type and number of atoms (C, H, N, O, and S) in an amino acid sequence
  // 
  // Description
  // To calculate atomic compostion of amino acid sequence
  // 
  // Examples
  // y = btd_atomiccomp("AHILLLCKQRSSPA")
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, Priyadharshini K, 2015


    
    l=length(ip);
    seq=mstr2sci(ip);
    
    for i=1:l
        A=grep(seq,"A");
        C=grep(seq,"C");
        D=grep(seq,"D");
        E=grep(seq,"E");
        F=grep(seq,"F");
        G=grep(seq,"G");
        H=grep(seq,"H");
        I=grep(seq,"I");
        K=grep(seq,"K");
        L=grep(seq,"L");
        M=grep(seq,"M");
        N=grep(seq,"N");
        P=grep(seq,"P");
        Q=grep(seq,"Q");
        R=grep(seq,"R");
        S=grep(seq,"S");
        T=grep(seq,"T");
        V=grep(seq,"V");
        W=grep(seq,"W");
        Y=grep(seq,"Y");
    end
    
    Ai=length(A);
    Ci=length(C);
    Di=length(D);
    Ei=length(E);
    Fi=length(F);
    Gi=length(G);
    Hi=length(H);
    Ii=length(I);
    Ki=length(K);
    Li=length(L);
    Mi=length(M);
    Ni=length(N);
    Pi=length(P);
    Qi=length(Q);
    Ri=length(R);
    Si=length(S);
    Ti=length(T);
    Vi=length(V);
    Wi=length(W);
    Yi=length(Y);

    //////H_atoms composition = sum of individual residues H_atoms - 2 ( number of residues - 1 )//
    H_atoms=((Ai*7)+(Ci*7)+(Di*7)+(Ei*9)+(Fi*11)+(Gi*5)+(Hi*9)+(Ii*13)+(Ki*14)+(Li*13)+(Mi*11)+(Ni*8)+(Pi*9)+(Qi*10)+(Ri*14)+(Si*7)+(Ti*9)+(Vi*11)+(Wi*12)+(Yi*11))-2*(l-1);
    N_atoms=((Ai*1)+(Ci*1)+(Di*1)+(Ei*1)+(Fi*1)+(Gi*1)+(Hi*3)+(Ii*1)+(Ki*2)+(Li*1)+(Mi*1)+(Ni*2)+(Pi*1)+(Qi*2)+(Ri*4)+(Si*1)+(Ti*1)+(Vi*1)+(Wi*2)+(Yi*1));
    O_atoms=((Ai*2)+(Ci*2)+(Di*4)+(Ei*4)+(Fi*2)+(Gi*2)+(Hi*2)+(Ii*2)+(Ki*2)+(Li*2)+(Mi*2)+(Ni*3)+(Pi*2)+(Qi*3)+(Ri*2)+(Si*3)+(Ti*3)+(Vi*2)+(Wi*2)+(Yi*3))-1*(l-1);
    C_atoms=((Ai*3)+(Ci*3)+(Di*4)+(Ei*5)+(Fi*9)+(Gi*2)+(Hi*6)+(Ii*6)+(Ki*6)+(Li*6)+(Mi*5)+(Ni*4)+(Pi*5)+(Qi*5)+(Ri*6)+(Si*3)+(Ti*4)+(Vi*5)+(Wi*11)+(Yi*9));
    S_atoms=((Ai*0)+(Ci*01)+(Di*0)+(Ei*0)+(Fi*0)+(Gi*0)+(Hi*0)+(Ii*0)+(Ki*0)+(Li*0)+(Mi*01)+(Ni*0)+(Pi*0)+(Qi*0)+(Ri*0)+(Si*0)+(Ti*0)+(Vi*0)+(Wi*0)+(Yi*0));
    
    a(1,1) = "H_atoms";
    a(1,2) = string(H_atoms);
    
    a(2,1) = "N_atoms";
    a(2,2) = string(N_atoms);
    
    a(3,1) = "O_atoms";
    a(3,2) = string(O_atoms);
    
     a(4,1) = "C_atoms";
     a(4,2) = string(C_atoms);
     
     a(5,1) = "S_atoms";
     a(5,2) = string(S_atoms);
    

//disp(sprintf("H_atoms=%d",H_atoms))
//disp(sprintf("N_atoms=%d",N_atoms))
//disp(sprintf("O_atoms=%d",O_atoms))
//disp(sprintf("C_atoms=%d",C_atoms))
//disp(sprintf("S_atoms=%d",S_atoms))


    //total number of atoms
    total=(H_atoms+N_atoms+O_atoms+C_atoms+S_atoms)

    //disp(sprintf("Total number of atoms=%d",total))

    a(6,1) = "Total number of atoms";
    a(6,2) = string(total);
    
    val = a;
    
endfunction
