function out=btd_atomicweight(x)
    
  // Atomic Weight
  // 
  // Calling Sequence
  //   y = btd_atomicweight ( x )
  // 
  // Parameters
  //   x : String of single-letter codes specifying an amino acid sequence 
  //   y : Atomic weight of amino acids
  // 
  // Description
  //  calculate the atomic weight  of C,N,O,H,S atoms in the given amino acid sequence x
  // 
  // Examples
  // y = btd_atomicweight('ACDEFGHIKLMNPQRSTVWY')
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, Priyadharshini K, 2015

    l=length(x);
    seq=mstr2sci(x);
    
    A=grep(seq,"A");
    C=grep(seq,"C");
    D=grep(seq,"D");
    E=grep(seq,"E");
    F=grep(seq,"F");
    G=grep(seq,"G");
    H=grep(seq,"H");
    I=grep(seq,"I");
    K=grep(seq,"K");
    L=grep(seq,"L");
    M=grep(seq,"M");
    N=grep(seq,"N");
    P=grep(seq,"P");
    Q=grep(seq,"Q");
    R=grep(seq,"R");
    S=grep(seq,"S");
    T=grep(seq,"T");
    V=grep(seq,"V");
    W=grep(seq,"W");
    Y=grep(seq,"Y");
    
    //    to calculate no of each aminoacid
    
    Ai=length(A);
    Ci=length(C);
    Di=length(D);
    Ei=length(E);
    Fi=length(F);
    Gi=length(G);
    Hi=length(H);
    Ii=length(I);
    Ki=length(K);
    Li=length(L);
    Mi=length(M);
    Ni=length(N);
    Pi=length(P);
    Qi=length(Q);
    Ri=length(R);
    Si=length(S);
    Ti=length(T);
    Vi=length(V);
    Wi=length(W);
    Yi=length(Y);
    
    //////H_atoms composition = sum of individual residues H_atoms - 2 ( number of residues - 1 )//
    H_atoms=((Ai*7)+(Ci*7)+(Di*7)+(Ei*9)+(Fi*11)+(Gi*5)+(Hi*9)+(Ii*13)+(Ki*14)+(Li*13)+(Mi*11)+(Ni*8)+(Pi*9)+(Qi*10)+(Ri*14)+(Si*7)+(Ti*9)+(Vi*11)+(Wi*12)+(Yi*11))-2*(l-1);
    
    N_atoms=((Ai*1)+(Ci*1)+(Di*1)+(Ei*1)+(Fi*1)+(Gi*1)+(Hi*3)+(Ii*1)+(Ki*2)+(Li*1)+(Mi*1)+(Ni*2)+(Pi*1)+(Qi*2)+(Ri*4)+(Si*1)+(Ti*1)+(Vi*1)+(Wi*2)+(Yi*1));
    
    O_atoms=((Ai*2)+(Ci*2)+(Di*4)+(Ei*4)+(Fi*2)+(Gi*2)+(Hi*2)+(Ii*2)+(Ki*2)+(Li*2)+(Mi*2)+(Ni*3)+(Pi*2)+(Qi*3)+(Ri*2)+(Si*3)+(Ti*3)+(Vi*2)+(Wi*2)+(Yi*3))-1*(l-1);
    
    C_atoms=((Ai*3)+(Ci*3)+(Di*4)+(Ei*5)+(Fi*9)+(Gi*2)+(Hi*6)+(Ii*6)+(Ki*6)+(Li*6)+(Mi*5)+(Ni*4)+(Pi*5)+(Qi*5)+(Ri*6)+(Si*3)+(Ti*4)+(Vi*5)+(Wi*11)+(Yi*9));
    
    S_atoms=((Ai*0)+(Ci*01)+(Di*0)+(Ei*0)+(Fi*0)+(Gi*0)+(Hi*0)+(Ii*0)+(Ki*0)+(Li*0)+(Mi*01)+(Ni*0)+(Pi*0)+(Qi*0)+(Ri*0)+(Si*0)+(Ti*0)+(Vi*0)+(Wi*0)+(Yi*0));
    
    
    //to calculate atomic weight
    //atomic mass  H 1.0079  C 12 0107  N 14.0067 O 15.9994 S 32.006
    
    H_wt=H_atoms*1.008;
    N_wt=N_atoms*14.007;
    O_wt=O_atoms*15.999;
    C_wt=C_atoms*12.011;
    S_wt=S_atoms*32.06;
    
    //Total atomic weight
    aw=H_wt+N_wt+O_wt+C_wt+S_wt;
    
    
    //To display
    out(1,1)="atomic weight :";
    out(1,2)=string(aw);
    out(1,3)="amu";
    
    //total number of atoms
    total=(H_atoms+N_atoms+O_atoms+C_atoms+S_atoms);
    out(2,1)="number of atoms :";
    out(2,2)=string(total);

endfunction

