function Out=btd_avg_hydrophobicity(x)
    
  // Average Hydrophobicity
  // 
  // Calling Sequence
  //   y = btd_avg_hydrophobicity(x)
  // 
  // Parameters
  //   x : String of single-letter codes specifying an amino acid sequence 
  //   y : Average hydrophobicity of amino acid sequence
  // 
  // Description
  //  Grand Average Hydrophobicity value of aminoacid sequence based on Kyte-Doolittle hydropathy values
  // 
  // Examples
  // y = btd_avg_hydrophobicity('ACDCEFGHIKLMNPQRSTVWY')
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, Priyadharshini K, 2015

    seq=mstr2sci(x)
    l=length(x)
    
    A=grep(seq,"A");
    C=grep(seq,"C");
    D=grep(seq,"D");
    E=grep(seq,"E");
    F=grep(seq,"F");
    G=grep(seq,"G");
    H=grep(seq,"H");
    I=grep(seq,"I");
    K=grep(seq,"K");
    L=grep(seq,"L");
    M=grep(seq,"M");
    N=grep(seq,"N");
    P=grep(seq,"P");
    Q=grep(seq,"Q");
    R=grep(seq,"R");
    S=grep(seq,"S");
    T=grep(seq,"T");
    V=grep(seq,"V");
    W=grep(seq,"W");
    Y=grep(seq,"Y");
    
    //to calculate average hydrophobicity of each aminoacid
    Ai=length(A);
    Aphb=(1.8*Ai);
    Ci=length(C);
    Cphb=(2.5*Ci);
    Di=length(D);
    Dphb=(-3.5*Di);
    Ei=length(E);
    Ephb=(-3.5*Ei);
    Fi=length(F);
    Fphb=(2.8*Fi);
    Gi=length(G);
    Gphb=(-0.4*Gi);
    Hi=length(H);
    Hphb=(-3.2*Hi);
    Ii=length(I);
    Iphb=(4.5*Ii);
    Ki=length(K);
    Kphb=(-3.9*Ki);
    Li=length(L);
    Lphb=(3.8*Li);
    Mi=length(M);
    Mphb=(1.9*Mi);
    Ni=length(N);
    Nphb=(-3.5*Ni);
    Pi=length(P);
    Pphb=(-1.6*Pi);
    Qi=length(Q);
    Qphb=(-3.5*Qi);
    Ri=length(R);
    Rphb=(-4.5*Ri);
    Si=length(S);
    Sphb=(-0.8*Si);
    Ti=length(T);
    Tphb=(-0.7*Ti);
    Vi=length(V);
    Vphb=(4.2*Vi);
    Wi=length(W);
    Wphb=(-0.9*Wi);
    Yi=length(Y);
    Yphb=(-1.3*Yi);

    //to sum
    total=Aphb+Cphb+Dphb+Ephb+Fphb+Gphb+Hphb+Iphb+Kphb+Lphb+Mphb+Nphb+Pphb+Qphb+Rphb+Sphb+Tphb+Vphb+Wphb+Yphb;
    //Grand average
    Out=total/l;
    
endfunction
