function op=btd_cleave(seq,ez)
    
  // Cleave
  // 
  // Calling Sequence
  //   y = btd_cleave ( x1, x2 )
  // 
  // Parameters
  //   x1 : String of single-letter codes specifying an amino acid sequence
  //   x2 : Enzyme
  //   y  : Fragments of aminoacid sequence from cleaveage
  // 
  // Description
  // To cleave aminoacid sequence at specific sites using enzymes.
  // 
  // Examples
  // y = btd_cleave("ADIIILLLAKLKKKRPAIMMM","Glu C")
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, Priyadharshini K, 2015

    
    l=length(seq);
    for i=1:l
        if (ez=="ARG-C" | ez=="ARG-C proteinase")
            op=strsplit(seq,"R");
        elseif(ez=="ASP-N" | ez=="ASP-N endopeptidase" )
            op=strsplit(seq,"D");
        elseif(ez=="BNPS" | ez=="BNPS-Skatole")
            op=strsplit(seq,"W");
        elseif(ez=="CASP1" | ez=="Caspase 1")
            op=strsplit(seq,"/(?<=[FWYL]\w[HAT])D(?=[^PEDQKR]/");
        elseif(ez=="CASP2" | ez=="Caspase 2")
            op=strsplit(seq,"/(?<=DVA)D(?=[^PEDQKR])/");
        elseif(ez=="CASP3" | ez=="Caspase 3")
            op=strsplit(seq,"/(?<=DMQ)D(?=[^PEDQKR])/");
        elseif(ez=="CASP4" | ez=="Caspase 4")
            op=strsplit(seq,"/(?<=LEV)D(?=[^PEDQKR])/");
        elseif(ez=="CASP5" | ez=="Caspase 5")
            op=strsplit(seq,"/(?<=[LW]EH)D/");
        elseif(ez=="CASP6" | ez=="Caspase 6")
            op=strsplit(seq,"/(?<=VE[HI])D(?=[^PEDQKR])/");
        elseif(ez=="CASP7" | ez=="Caspase 7")
            op=strsplit(seq,"/(?<=DEV)D(?=[^PEDQKR])/");
        elseif(ez=="CASP8" | ez=="Caspase 8")
            op=strsplit(seq,"/(?<=[IL]ET)D(?=[^PEDQKR])/");
        elseif(ez=="CASP9" | ez=="Caspase 9")
            op=strsplit(seq,"/(?<=LEH)D");
        elseif(ez=="CASP10" | ez=="Caspase 10")
            op=strsplit(seq,"/(?<=IEA)D/");
        elseif(ez=="CH-HI" | ez=="Chymotrypsin- high specificity")
            op=strsplit(seq,"/([FY](?=[^P]))|(W(?=[^MP]))/");
        elseif(ez=="CH-LO" | ez=="Chymotrypsin- low specificity")
            op=strsplit(seq,"/([FLY](?=[^P]))|(W(?=[^MP]))| (M(?=[^PY]))|(H(?=[^DMPW]))/");
        elseif(ez=="CLOST" | ez=="Clostripain")
            op=strsplit(seq,"R");
        elseif(ez=="CNBR")
            op=strsplit(seq,"M");
        elseif(ez=="ENTKIN" | ez=="Enterokinase")
            op=strsplit(seq,"/(?<=[DN][DN][DN])K/");
        elseif(ez=="FACTXA" | ez=="Factor XA")
            op=strsplit(seq,"/(?<=[AFGILTVM][DE]G)R/");
        elseif(ez=="FORMIC" | ez=="Formic acid")
            op=strsplit(seq,"D");
        elseif(ez=="GLUEND" | ez=="Glutamyl endopeptidase")
            op=strsplit(seq,"E");
        elseif(ez=="GRANB" | ez=="Granzyme B")
            op=strsplit(seq,"/(?<=IEP)D/");
        elseif(ez=="HYDROX" | ez=="Hydroxylamine")
            op=strsplit(seq,"/N(?=G)/");
        elseif(ez=="IODOB" | ez=="Iodosobenzoic acid")
            op=strsplit(seq,"W");
        elseif(ez=="LYSC" | ez=="Lysc")
            op=strsplit(seq,"K");
        elseif(ez=="NTCB")
            op=strsplit(seq,"C");
        elseif(ez=="PEPS" | ez=="Pepsin PH = 1.3")
            op=strsplit(seq,"/((?<=[^HKR][^P])[^R](?=[FLWY][^P]))| ((?<=[^HKR][^P])[FLWY](?=\w[^P]))/");
        elseif(ez=="PEPS2" | ez=="Pepsin PH > 2")
            op=strsplit(seq,"/((?<=[^HKR][^P])[^R](?=[FL][^P]))| ((?<=[^HKR][^P])[FL](?=\w[^P]))/");
        elseif(ez=="PROEND" | ez=="Proline endopeptidase")
            op=strsplit(seq,"/(?<=[HKR])P(?=[^P])/");
        elseif(ez=="PROTK" | ez=="Proteinase K")
            op=strsplit(seq,"/[AEFILTVWY]/");
        elseif(ez=="STAPHP" | ez=="Staphylococcal peptidase I")
            op=strsplit(seq,"/(?<=[^E])/");
        elseif(ez=="THERMO" | ez=="Thermolysin")
            op=strsplit(seq,"/[^DE](?=[AFILMV])/");
        elseif(ez=="THROMB" | ez=="Thrombin")
            op=strsplit(seq,"/((?<=\w\wG)R(?=G))| ((?<=[AFGILTVM][AFGILTVWA]P)R(?=[^DE][^DE]))/");
        elseif(ez=="TRYPS" | ez=="Trypsin")
            op=strsplit(seq,"/((?<=\w)[KR](?=[^P]))| ((?<=W)K(?=P))|((?<=M)R(?=P))/");
        elseif ez=="Chymotyrpsin"
            op=strsplit(seq,"/[WYF][^P]/");
        elseif ez=="Glu C"
            op=strsplit(seq,"/[ED][^P]/");
        end
    end
endfunction
