function Out = btd_entropyamino(str)
    
  // Entropy of Amino Acid
  // 
  // Calling Sequence
  //   y = btd_entropyamino(x)
  // 
  // Parameters
  //   x : String of single-letter codes specifying an amino acid sequence 
  //   y : Entropy value of amino acid sequence
  // 
  // Description
  //  The statistical parameter Entropy of given aminoacid sequence
  // 
  // Examples
  // y = btd_entropyamino("ACDEFGHIKLMNPQRSTVWY")
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, Priyadharshini K, Biji C L, 2015


    str1 = strcat(str,"","c"); //concatenate the columns
    str2 = strcat(str1,"","r"); //concatenate the rows
    str3 = mstr2sci(str2);
    n = size(str3,"c");
     
    d = mstr2sci('ACDEFGHIKLMNPQRSTVWY');
    m = size(d,"c");
    
    //To find the number of each aminoacid present
    naa = zeros(m,1);
    for i=1:m;
        naa(i) = length(find(str3==d(i)));
    end;
    
    //To calculate the proportion of each aminoacid
    Proportion = naa/n;
    y=size(Proportion,"r")
    i=1;
    T=[];
    for j=1:y;
        if Proportion(j) > 0
            T(i)=Proportion(j);
            i=i+1;
        end
    end
    
    //To calculate entropy
    Out = -sum(T.*log2(T))

endfunction
