function Out=btd_ext_coefficients(x)
    
  // Extinction coefficients of amino acid sequence 
  // 
  // Calling Sequence
  //   y = btd_ext_coefficients(x)
  // 
  // Parameters
  //   x : String of single-letter codes specifying an amino acid sequence
  //   y : Extinction Coefficients of amino acid sequence
  // 
  // Description
  //  Extinction Coefficients of aminoacid sequence (for proteins in water measured at 280 nm)
  // 
  // Examples
  // y = btd_ext_coefficients('ACDEFGHIKLMNPQRSTVWY')
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, Priyadharshini K, 2015

    seq=mstr2sci(x)
    l=length(x)
    
    C=grep(seq,"C");
    Ci=length(C)
    W=grep(seq,"W");
    Wi=length(W)
    Y=grep(seq,"Y");
    Yi=length(Y)

   //to calcluate c of n numbers
    if modulo(Ci,2) == 0 then
        Ext(C)=125*Ci/2
        Ext(Y)=1490*Yi
        Ext(W)=5500*Wi
        E=Ext(Y)+Ext(W)+Ext(C);
    else
        Cc=Ci-1
        Ext(C)=125*Cc/2
        Ext(Y)=1490*Yi
        Ext(W)=5500*Wi
        E=Ext(Y)+Ext(W)+Ext(C);
    end

    Out(1,1)="Extinction Coefficients:"
    Out(1,2)=string(E)
    Out(1,3)="M−1⋅cm−1"

endfunction
