function Out=btd_exterior_volume(x)
    
  // Exterior Volume of amino acid sequence
  // 
  // Calling Sequence
  //   y = btd_exterior_volume(x)
  // 
  // Parameters
  //   x : String of single-letter codes specifying an amino acid sequence
  //   y : Exterior Volume of amino acid sequence
  // 
  // Description
  //  Approximate Exterior Volume of aminoacid sequence and its unit is A3
  // 
  // Examples
  // y = btd_exterior_volume('ACDEFGHIKLMNPQRSTVWY')
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, Priyadharshini K, 2015


    l=length(x);
    seq=mstr2sci(x);
    
    A=grep(seq,"A");
    B=grep(seq,"B");
    C=grep(seq,"C");
    D=grep(seq,"D");
    E=grep(seq,"E");
    F=grep(seq,"F");
    G=grep(seq,"G");
    H=grep(seq,"H");
    I=grep(seq,"I");
    K=grep(seq,"K");
    L=grep(seq,"L");
    M=grep(seq,"M");
    N=grep(seq,"N");
    P=grep(seq,"P");
    Q=grep(seq,"Q");
    R=grep(seq,"R");
    S=grep(seq,"S");
    T=grep(seq,"T");
    V=grep(seq,"V");
    W=grep(seq,"W");
    Y=grep(seq,"Y");
    Z=grep(seq,"Z");


    //to find mol wt of type i
    Ai=length(A);
        PVa=Ai*88.6;
        IVa=Ai*88.6*0.38;
    Ci=length(C);
        PVc=Ci*108.5;
        IVc=Ci*108.5*0.45;
    Di=length(D);
        PVd=Di*111.1;
        IVd=Di*111.1*0.15;
    Ei=length(E);
        PVe=Ei*138.4;
        IVe=Ei*138.4*0.18;
    Fi=length(F);
        PVf=Fi*189.9;
        IVf=Fi*189.9*0.50;
    Gi=length(G);
        PVg=Gi*60.1;
        IVg=Gi*60.1*0.36;
   Hi=length(H);
        PVh=Hi*153.2;
        IVh=Hi*153.2*0.17;
    Ii=length(I);
        PVi=Ii*166.7;
        IVi=Ii*166.7*0.60;
    Ki=length(K);
        PVk=Ki*168.6;
        IVk=Ki*168.6*0.03;
    Li=length(L);
        PVl=Li*166.7;
        IVl=Li*166.7*0.45;
    Mi=length(M);
        PVm=Mi*162.9;
        IVm=Mi*162.9*0.40;
    Ni=length(N);
        PVn=Ni*117.7;
        IVn=Ni*117.7*0.12;
    Pi=length(P);
        PVp=Pi*122.7;
        IVp=Pi*122.7*0.18;
    Qi=length(Q);
        PVq=Qi*143.9;
        IVq=Qi*143.9*0.07;
    Ri=length(R);
        PVr=Ri*173.4;
        IVr=Ri*173.4*0.01;
    Si=length(S);
        PVs=Si*89.0;
        IVs=Si*89.0*0.22;
    Ti=length(T);
        PVt=Ti*116.1;
        IVt=Ti*116.1*0.23;
    Vi=length(V);
        PVv=Vi*140.0;
        IVv=Vi*140.0*0.54;
    Wi=length(W);
        PVw=Wi*227.8;
        IVw=Wi*227.8*0.27;
    Yi=length(Y);
        PVy=Yi*193.6;
        IVy=Yi*193.6*0.15;

    //Packing Volume
    PV=PVa+PVc+PVd+PVe+PVf+PVg+PVh+PVi+PVk+PVl+PVm+PVn+PVp+PVq+PVr+PVs+PVt+PVv+PVw+PVy;
    //Interior Volume
    Vint=IVa+IVc+IVd+IVe+IVf+IVg+IVh+IVi+IVk+IVl+IVm+IVn+IVp+IVq+IVr+IVs+IVt+IVv+IVw+IVy;
    //Exterior Volume
    Vext=PV-Vint;
    Out(1,1)="Approximate Exterior Volume:";
    Out(1,2)=string(Vext);
    Out(1,3)="Å^3";
    
endfunction
