function Out=btd_interior_volume(x)
    
  // Interior Volume of amino acid sequence
  // 
  // Calling Sequence
  //   y = btd_exterior_volume(x)
  // 
  // Parameters
  //   x : String of single-letter codes specifying an amino acid sequence
  //   y : Interior Volume of amino acid sequence
  // 
  // Description
  //  Approximate Interior Volume of aminoacid sequence and its unit is A3
  // 
  // Examples
  // y = btd_interior_volume('ACDEFGHIKLMNPQRSTVWY')
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, Priyadharshini K, 2015



    l=length(x);
    seq=mstr2sci(x);
    
    A=grep(seq,"A");
    B=grep(seq,"B");
    C=grep(seq,"C");
    D=grep(seq,"D");
    E=grep(seq,"E");
    F=grep(seq,"F");
    G=grep(seq,"G");
    H=grep(seq,"H");
    I=grep(seq,"I");
    K=grep(seq,"K");
    L=grep(seq,"L");
    M=grep(seq,"M");
    N=grep(seq,"N");
    P=grep(seq,"P");
    Q=grep(seq,"Q");
    R=grep(seq,"R");
    S=grep(seq,"S");
    T=grep(seq,"T");
    V=grep(seq,"V");
    W=grep(seq,"W");
    Y=grep(seq,"Y");
    Z=grep(seq,"Z");
    
    //to find IV of type i
    //Vint=sum Ai*FBi*Vi
    Ai=length(A);
        IVa=Ai*88.6*0.38;
    Ci=length(C);
        IVc=Ci*108.5*0.45;
    Di=length(D);
        IVd=Di*111.1*0.15;
    Ei=length(E);
        IVe=Ei*138.4*0.18;
    Fi=length(F);
        IVf=Fi*189.9*0.50;
    Gi=length(G);
        IVg=Gi*60.1*0.36;
   Hi=length(H);
        IVh=Hi*153.2*0.17;
    Ii=length(I);
        IVi=Ii*166.7*0.60;
    Ki=length(K);
        IVk=Ki*168.6*0.03;
    Li=length(L);
        IVl=Li*166.7*0.45;
    Mi=length(M);
        IVm=Mi*162.9*0.40;
    Ni=length(N);
        IVn=Ni*117.7*0.12;
    Pi=length(P);
        IVp=Pi*122.7*0.18;
    Qi=length(Q);
        IVq=Qi*143.9*0.07;
    Ri=length(R);
        IVr=Ri*173.4*0.01;
    Si=length(S);
        IVs=Si*89.0*0.22;
    Ti=length(T);
        IVt=Ti*116.1*0.23;
    Vi=length(V);
        IVv=Vi*140.0*0.54;
    Wi=length(W);
        IVw=Wi*227.8*0.27;
    Yi=length(Y);
        IVy=Yi*193.6*0.15;
        
    Vint=IVa+IVc+IVd+IVe+IVf+IVg+IVh+IVi+IVk+IVl+IVm+IVn+IVp+IVq+IVr+IVs+IVt+IVv+IVw+IVy;
    Out(1,1)="Approximate Interior Volume:";
    Out(1,2)=string(Vint);
    Out(1,3)="Å^3";
    
endfunction
