function out = btd_isoelectricpoint(x)
    
  // Isoelectric Point
  // 
  // Calling Sequence
  //   y = btd_isoelectricpoint(x)
  // 
  // Parameters
  //   x : String of single-letter codes specifying an amino acid sequence
  //   y : Isoelectricpoint of amino acid sequence
  // 
  // Description
  //  Isoelectric point represents a pH value where given protein's net charge becomes zero
  // 
  // Examples
  // y = btd_isoelectricpoint('ACDEFGHIKLMNPQRSTVWY')
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, Priyadharshini K, 2015


    seq=mstr2sci(x);
    l=length(x);
        
    C=grep(seq,'C');
        Ci=length(C);
    D=grep(seq,'D');
        Di=length(D);
    E=grep(seq,'E');
        Ei=length(E);
    H=grep(seq,'H');
        Hi=length(H);
    K=grep(seq,'K');
        Ki=length(K);
    R=grep(seq,'R');
        Ri=length(R);
    Y=grep(seq,'Y');
        Yi=length(Y);


    h=1;
    p=[];
    for i=3:0.001:14;
        p(h)=i;
        h=h+1;
    end

    NQ=[];
    a=1;
    
    for pH=3:0.001:14
        QN1=-1/(1+10^(3.65-pH)); //COOH   NEG                     
        QN2=-Di/(1+10^(3.9-pH));//D   NEG
        QN3=-Ei/(1+10^(4.07-pH));  //E   NEG        
        QN4=-Ci/(1+10^(8.18-pH));  //C      NEG   
        QN5=-Yi/(1+10^(10.46-pH));   //Y     NEG
        QP1=Hi/(1+10^(pH-6.04));        //H    POS
        QP2=1/(1+10^(pH-8.2));                //NH2    POS
        QP3=Ki/(1+10^(pH-10.54));           //K    POS
        QP4=Ri/(1+10^(pH-12.48));           // R   POS
    
        NQ(a)=QN1+QN2+QN3+QN4+QN5+QP1+QP2+QP3+QP4;
        a = a+1;
    end
    
    NQi=round(NQ);
   
    j=1;
    k = [];
    len = length(NQi);
   
    for b = 1:len
        if ( NQi(b) == 0)
            k(j)=p(b);
            j=j+1;
        end
    end
    
    val =mean(k, 'r');
    out(1,1)='Approximate pI value:';
    out(1,2)=string(val);
    
endfunction
