function ma=btd_molarabsortivity(x)
    
  // Molar Absortivity
  // 
  // Calling Sequence
  //   y = btd_molarabsortivity(x)
  // 
  // Parameters
  //   x : String of single-letter codes specifying an amino acid sequence
  //   y : Molar Absortivity of amino acid sequence
  // 
  // Description
  //  Molar absortivity/absorbance of aminoacid sequence 
  // 
  // Examples
  // y = btd_molarabsortivity('ACDEFGHIKLMNPQRSTVWY')
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, Priyadharshini K, 2015


    seq=mstr2sci(x);
    l=length(x);
    
    A=grep(seq,"A");
    B=grep(seq,"B");
    C=grep(seq,"C");
    D=grep(seq,"D");
    E=grep(seq,"E");
    F=grep(seq,"F");
    G=grep(seq,"G");
    H=grep(seq,"H");
    I=grep(seq,"I");
    K=grep(seq,"K");
    L=grep(seq,"L");
    M=grep(seq,"M");
    N=grep(seq,"N");
    P=grep(seq,"P");
    Q=grep(seq,"Q");
    R=grep(seq,"R");
    S=grep(seq,"S");
    T=grep(seq,"T");
    V=grep(seq,"V");
    W=grep(seq,"W");
    Y=grep(seq,"Y");
    Z=grep(seq,"Z");
    
    //to calculate mol_wt of each aminoacid
    Ai=length(A);
    Awt=(89.09*Ai);
    Bi=length(B);
    Bwt=(132.61*Bi);
    Ci=length(C);
    Cwt=(121.15*Ci);
    Di=length(D);
    Dwt=(133.10*Di);
    Ei=length(E);
    Ewt=(147.13*Ei);
    Fi=length(F);
    Fwt=(165.19*Fi);
    Gi=length(G);
    Gwt=(75.07*Gi);
    Hi=length(H);
    Hwt=(155.16*Hi);
    Ii=length(I);
    Iwt=(131.17*Ii);
    Ki=length(K);
    Kwt=(146.19*Ki);
    Li=length(L);
    Lwt=(131.17*Li);
    Mi=length(M);
    Mwt=(149.21*Mi);
    Ni=length(N);
    Nwt=(132.12*Ni);
    Pi=length(P);
    Pwt=(115.13*Pi);
    Qi=length(Q);
    Qwt=(146.15*Qi);
    Ri=length(R);
    Rwt=(174.20*Ri);
    Si=length(S);
    Swt=(105.09*Si);
    Ti=length(T);
    Twt=(119.12*Ti);
    Vi=length(V);
    Vwt=(117.15*Vi);
    Wi=length(W);
    Wwt=(204.23*Wi);
    Yi=length(Y);
    Ywt=(181.19*Yi);
    Zi=length(Z);
    Zwt=(146.64*Zi);
    
    //Molecular weight = sum of individual residues weights - water molecular weight ´ ( number of residues - 1 )//
    // where, water molecular weight = 18.015//

    molweight=(Awt+Bwt+Cwt+Dwt+Ewt+Fwt+Gwt+Hwt+Iwt+Kwt+Lwt+Mwt+Nwt+Pwt+Qwt+Rwt+Swt+Twt+Vwt+Wwt+Ywt+Zwt)-18.015*(l-1);
    
    //to calculate ext_coefficients
    if modulo(Ci,2) == 0 then
        Ext(C)=125*Ci/2;
        Ext(Y)=1490*Yi;
        Ext(W)=5500*Wi;
        E=Ext(Y)+Ext(W)+Ext(C);
    else
        Cc=Ci-1;
        Ext(C)=125*Cc/2;
        Ext(Y)=1490*Yi;
        Ext(W)=5500*Wi;
        E=Ext(Y)+Ext(W)+Ext(C);
    end
    
    //to calculate molar absortivity
    ma=E/molweight;
endfunction
