function Proportion = btd_ntdensity(DNA)
    
  
  // Nucleotide Density
  // 
  // Calling Sequence
  //   y = btd_ntdensity ( x )
  // 
  // Parameters
  //   x : String of single-letter codes specifying a Nucleotide sequence 
  //   y : Bar Graph representing density of nucleotides
  // 
  // Description
  //  Plot the density of nucleotides along the given sequence x.and display its proportion
  // 
  // Examples
  // y = btd_ntdensity("ACTGATCGAATATGCGAGCGA")
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, Priyadharshini K, 2015

    str1 = strcat(DNA,"","c");//concatenate the columns
    str2 = strcat(str1,"","r");//concatenate the rows
    str3 = mstr2sci(str2);
    n = size(str3,"c");
    d = mstr2sci('ACGT');
    m = size(d,"c");
    
    //To find the number of each nucleotide present
    naa = zeros(m,1);
    for i=1:m;
        naa(i) = length(find(str3==d(i)));
    end;
    
    //To calculate the proportion of each nucleotide
    Proportion = naa/n;
    
    
    //To plot the proportion of each nucleotide in the given sequence
    bar(1:m,Proportion);
    set(gca(),"data_bounds",matrix([0,5,0,1],2,-1));//User can change the axis bounds accordingly!!!
    a=get("current_axes")
    a.x_ticks = tlist(["ticks"], (0:4)', ["$ $";"$A$";"$C$";"$G$";"$T$"]);
    
    //User can change the following things according to their preference and requirement.
    //...................................................................................//
    a.font_color = 5;
    a.font_size = 3;
    
    legend(': NUCLEOTIDE BASES');
    title('Proportions of Each Nucleotide in the Sequence',"fontsize",4,"color","red");
    ylabel('PROPORTION',"fontsize",4,"color","red");
    
endfunction
