function Out=btd_psv(x)
    
  // Partial Specific Volume 
  // 
  // Calling Sequence
  //   y = btd_proteinradius ( x )
  // 
  // Parameters
  //   x : String of single-letter codes specifying an amino acid sequence 
  //   y : Partial specific volume of amino acid sequence
  // 
  // Description
  //  Approximate Partial Specific Volume of aminoacid sequence and its unit is ml/g
  // 
  // Examples
  // y = btd_psv('ACDEFGHIKLMNPQRSTVWY')
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, Priyadharshini K, 2015

    l=length(x);
    seq=mstr2sci(x);
    
    A=grep(seq,"A");
    B=grep(seq,"B");
    C=grep(seq,"C");
    D=grep(seq,"D");
    E=grep(seq,"E");
    F=grep(seq,"F");
    G=grep(seq,"G");
    H=grep(seq,"H");
    I=grep(seq,"I");
    K=grep(seq,"K");
    L=grep(seq,"L");
    M=grep(seq,"M");
    N=grep(seq,"N");
    P=grep(seq,"P");
    Q=grep(seq,"Q");
    R=grep(seq,"R");
    S=grep(seq,"S");
    T=grep(seq,"T");
    V=grep(seq,"V");
    W=grep(seq,"W");
    Y=grep(seq,"Y");
    Z=grep(seq,"Z");
    
//to find mol wt of type i
    Ai=length(A);
        Awt=(89.09*Ai);
    Ci=length(C);
        Cwt=(121.15*Ci);
    Di=length(D);
        Dwt=(133.10*Di);
    Ei=length(E);
        Ewt=(147.13*Ei);
    Fi=length(F);
        Fwt=(165.19*Fi);
    Gi=length(G);
        Gwt=(75.07*Gi);
    Hi=length(H);
        Hwt=(155.16*Hi);
    Ii=length(I);
        Iwt=(131.17*Ii);
    Ki=length(K);
        Kwt=(146.19*Ki);
    Li=length(L);
        Lwt=(131.17*Li);
    Mi=length(M);
        Mwt=(149.21*Mi);
    Ni=length(N);
        Nwt=(132.12*Ni);
    Pi=length(P);
        Pwt=(115.13*Pi);
    Qi=length(Q);
        Qwt=(146.15*Qi);
    Ri=length(R);
        Rwt=(174.20*Ri);
    Si=length(S);
        Swt=(105.09*Si);
    Ti=length(T);
        Twt=(119.12*Ti);
    Vi=length(V);
        Vwt=(117.15*Vi);
    Wi=length(W);
        Wwt=(204.23*Wi);
    Yi=length(Y);
        Ywt=(181.19*Yi);

//to find vol of each aminoacid

        PVa=Ai*88.6;
        PVc=Ci*108.5;
        PVd=Di*111.1;
        PVe=Ei*138.4;
        PVf=Fi*189.9;
        PVg=Gi*60.1;
        PVh=Hi*153.2;
        PVi=Ii*166.7;
        PVk=Ki*168.6;
        PVl=Li*166.7;
        PVm=Mi*162.9;
        PVn=Ni*117.7;
        PVp=Pi*122.7;
        PVq=Qi*143.9;
        PVr=Ri*173.4;
        PVs=Si*89.0;
        PVt=Ti*116.1;
        PVv=Vi*140.0;
        PVw=Wi*227.8;
        PVy=Yi*193.6;
    //////////////////////////////////
    molweight=(Awt+Cwt+Dwt+Ewt+Fwt+Gwt+Hwt+Iwt+Kwt+Lwt+Mwt+Nwt+Pwt+Qwt+Rwt+Swt+Twt+Vwt+Wwt+Ywt)-18.015*(l-1);
    PV=PVa+PVc+PVd+PVe+PVf+PVg+PVh+PVi+PVk+PVl+PVm+PVn+PVp+PVq+PVr+PVs+PVt+PVv+PVw+PVy;
    psv=PV/molweight;
    Out(1,1)="Approximate Partial Specific Volume:";
    Out(1,2)=string(psv);
    Out(1,3)="ml/g";
    
endfunction
