function seqr = btd_seqrcomplement(n)
    
  // Sequence Reverse Complement
  // 
  // Calling Sequence
  //   y = btd_seqrcomplement ( x )
  // 
  // Parameters
  //   x : String of single-letter codes specifying a nucleotide sequence
  //   y : Complementary strand of a DNA or RNA nucleotide sequence.
  // 
  // Description
  // To find reverse complementary strand of nucleotide sequence
  // 
  // Examples
  // y = btd_seqrcomplement("ATGC")
  //
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, 2015


    l = length(n);
    revs = strrev(n);
    arr = mstr2sci(revs);
    flag = 0;
    
    //checking whether sequence is DNA or RNA
    ////flag=1 means sequence is an RNA and DNA otherwise
    for i = 1:l
        if arr(i) == 'U' then
            flag = 1;
        end
    end
    
    //replacing each code with its complement
    for j = 1:l
        select arr(j)
        case "A" then
            if flag == 0 then
                out(j) = 'T';
            else
                out(j) = 'U';
            end
        case "C" then
            out(j) = 'G';
        case "G" then
            out(j) = 'C';
        case "T" then
            out(j) = 'A';
        case "U" then
            out(j) = 'A';
        case "R" then
            out(j) = 'Y';
        case "Y" then
            out(j) = 'R';
        case "K" then
            out(j) = 'M';
        case "M" then
            out(j) = 'K';
        case "S" then
            out(j) = 'S';
        case "W" then
            out(j) = 'W';
        case "B" then
            out(j) = 'V';
        case "D" then
            out(j) = 'H';
        case "H" then
            out(j) = 'D';
        case "V" then
            out(j) = 'B';
        case "N" then
            out(j) = 'N';
        else
            out(j) = '*';           
        end
    end
    
    seqr = strcat(out);
    
endfunction
