/* ====================================================================== */
  // Authors
  // Dr.Achuthsankar S Nair, Dr. Umesh P, Deepthi S, 2015
/* ====================================================================== */

package org.scilab.contrib.BTD;

public class btd 
{

/* ====================================================================== */
/* 									  */
/* 		SUM EXAMPLE TOOLBOX SKELETON    			  */
/*									  */
/* ====================================================================== */

	public static double sum(double a, double b) 
	{
		return a + b;
	}

	
/* ====================================================================== */
/* 									  */
/* 		NEEDLEMAN WUNSCH SEQUENCE ALIGNMENT			  */
/*		 
  // Calling Sequence
  //   y = btd_nwalign ( x1, x2 )
  // 
  // Parameters
  //   x1 : String of single-letter codes specifying a query nucleotide sequence
  //   x2 : String of single-letter codes specifying a target nucleotide sequence
  //   y  : Alligned sequences
  // 
  // Description
  // Needleman-Wunsch Global alignment of two nucleotide sequences
  // 
  // Examples
  // y = btd.nwalign("ATGTCGAT","ATGCCAT")
 						  
/* ====================================================================== */

	
       
        public static String[][] nwalign(String seqA,String seqB) 
	{
		//declaration for nwalign
		char[] mSeqA;
		char[] mSeqB;
	
		int[][] mD;
		int mScore;
		String mAlignmentSeqA = "";
		String mAlignmentSeqB = "";
		
		//Align holds the output allignment in a matrix. Purpose : ease of returning value to Scilab
		String[][] Align = new String[2][2];
		
        	int weight1;
        	int weight2; 
        	//step:1 initalisation
                mSeqA=seqA.toCharArray();
                mSeqB=seqB.toCharArray();
                mD = new int[mSeqA.length + 1][mSeqB.length + 1];
                
		for (int i = 0; i <= mSeqA.length; i++) 
		{
			for (int j = 0; j <= mSeqB.length; j++) 
			{
                                if (i == 0) {
                                        mD[i][j] = -j;
                                } else if (j == 0) {
                                        mD[i][j] = -i;
                                } else {
                                        mD[i][j] = 0;
                                }
                        }
                }
                //step:2 scoring process
                for (int i = 1; i <= mSeqA.length; i++) 
		{
                        for (int j = 1; j <= mSeqB.length; j++) 
			{
				if (mSeqA[i - 1] == mSeqB[j - 1]) {
		                        weight1 = 1;
                		} else {
                        		weight1 = -1;
				}
                                int scoreDiag = mD[i-1][j-1] + weight1;// weight(i, j);
                                int scoreLeft = mD[i][j-1] - 1;
                                int scoreUp = mD[i-1][j] - 1;
                                mD[i][j] = Math.max(Math.max(scoreDiag, scoreLeft), scoreUp);
                        }
                }
                //step:3 traceback
                int i = mSeqA.length;
                int j = mSeqB.length;
                mScore = mD[i][j];
                while (i > 0 && j > 0) 
		{        
			if (mSeqA[i - 1] == mSeqB[j - 1]) {
		                        weight2 = 1;
                		} else {
                        		weight2 = -1;
				}                
                        if (mD[i][j] == mD[i-1][j-1] + weight2) //weight(i, j)) 
			{                          
                                mAlignmentSeqA += mSeqA[i-1];
                                mAlignmentSeqB += mSeqB[j-1];
                                i--;
                                j--;                            
                                continue;
                        } 
			else if (mD[i][j] == mD[i][j-1] - 1) 
			{
                                mAlignmentSeqA += "-";
                                mAlignmentSeqB += mSeqB[j-1];
                                j--;
                                continue;
                        } 
			else 
			{
                                mAlignmentSeqA += mSeqA[i-1];
                                mAlignmentSeqB += "-";
                                i--;
                                continue;
                        }
                }
                mAlignmentSeqA = new StringBuffer(mAlignmentSeqA).reverse().toString();
                mAlignmentSeqB = new StringBuffer(mAlignmentSeqB).reverse().toString();

		Align[0][0] = mAlignmentSeqA;
                Align[0][1] = mAlignmentSeqB;

		return Align;
        }
        

/* ====================================================================== */
/* 									  */
/* 		SMITH WATERMAN SEQUENCE ALIGNMENT			  */
/*						  
  // Calling Sequence
  //   y = btd_swalign ( x1, x2 )
  // 
  // Parameters
  //   x1 : String of single-letter codes specifying a query nucleotide sequence
  //   x2 : String of single-letter codes specifying a target nucleotide sequence
  //   y  : Alligned sequences
  // 
  // Description
  // Smith Waterman Local alignment of two nucleotide sequences
  // 
  // Examples
  // y = btd.swalign("ATGTCGAT","ATGCCAT")
			  
/* ====================================================================== */

	
    
    	public static String[][] swalign(String sseqA, String sseqB) 
	{
		
		char[] sSeqA;
		char[] sSeqB;
    		int[][] sD;
    		int sScore;
    		String[][] sAlign = new String[2][2];
    		String sAlignmentSeqA = "";
    		String sAlignmentSeqB = "";

		int sweight1;
        	int sweight2; 

		// initialization
		sSeqA=sseqA.toCharArray();
                sSeqB=sseqB.toCharArray();               
                sD = new int[sSeqA.length + 1][sSeqB.length + 1];
        	for (int i = 0; i <= sSeqA.length; i++) {
            		sD[i][0] = 0;                  
        	}
        	for (int j = 0; j <= sSeqB.length; j++) {
            		sD[0][j] = 0;
        	}
        
        	//process
        	for (int i = 1; i <= sSeqA.length; i++) {
            		for (int j = 1; j <= sSeqB.length; j++) {
				if (sSeqA[i - 1] == sSeqB[j - 1]) {
            				sweight1 = 2;
        			} else {
            				sweight1 = -1;
        			}
                		int scoreDiag = sD[i-1][j-1] + sweight1;
	                	int scoreLeft = sD[i][j-1] - 1;
                		int scoreUp = sD[i-1][j] - 1;
                		sD[i][j] = Math.max(Math.max(Math.max(scoreDiag, scoreLeft), scoreUp), 0);
            		}
        	}
        
        	//backtrack
        	int i = 1;
        	int j = 1;
        	int max = sD[i][j];
        	for (int k = 1; k <= sSeqA.length; k++) {
            		for (int l = 1; l <= sSeqB.length; l++) {
                		if (sD[k][l] > max) {
                    			i = k;
                    			j = l;
                    			max = sD[k][l];
                		}
            		}
       		}        
        
        	sScore = sD[i][j];
        
        	int k = sSeqA.length;
        	int l = sSeqB.length;           
        
        	while (k > i) {
            		sAlignmentSeqB += "-";
            		sAlignmentSeqA += sSeqA[k - 1];
            		k--;
        	}
        	while (l > j) {
            		sAlignmentSeqA += "-";
            		sAlignmentSeqB += sSeqB[l - 1];
            		l--;
        	}
        
        	while (sD[i][j] != 0) { 
			if (sSeqA[i - 1] == sSeqB[j - 1]) {
            			sweight2 = 2;
        		} else {
            			sweight2 = -1;
        		}               
            		if (sD[i][j] == sD[i-1][j-1] + sweight2) {                          
                		sAlignmentSeqA += sSeqA[i-1];
                		sAlignmentSeqB += sSeqB[j-1];
                		i--;
                		j--;                            
                		continue;
            		} else if (sD[i][j] == sD[i][j-1] - 1) {
                		sAlignmentSeqA += "-";
                		sAlignmentSeqB += sSeqB[j-1];
                		j--;
                		continue;
            		} else {
                		sAlignmentSeqA += sSeqA[i-1];
                		sAlignmentSeqB += "-";
                		i--;
                		continue;
            		}
        	}
        
        	while (i > 0) {
            		sAlignmentSeqB += "-";
            		sAlignmentSeqA += sSeqA[i - 1];
            		i--;
        	}
        	while (j > 0) {
            		sAlignmentSeqA += "-";
            		sAlignmentSeqB += sSeqB[j - 1];
            		j--;
        	}
               
        	sAlignmentSeqA = new StringBuffer(sAlignmentSeqA).reverse().toString();
        	sAlignmentSeqB = new StringBuffer(sAlignmentSeqB).reverse().toString();
        
        	sAlign[0][0] = sAlignmentSeqA;
        	sAlign[0][1] = sAlignmentSeqB;

		return sAlign;
    	}
    
       
}

